Task

Struct Task 

pub struct Task<I, O> { /* private fields */ }
A task is a unit of work that can be executed by a worker. See Hatchet.task() for more information.

Implementations

Source

impl<I, O> Task<I, O>
where I: Serialize + for<'de> Deserialize<'de> + Send + 'static, O: Serialize + Send + 'static,

pub fn add_parent<J, P>(self, parent: &Task<J, P>) -> Self

pub async fn schedule( &self, trigger_at: DateTime<Utc>, input: &I, options: Option<&ScheduleOptions>, ) -> Result<ScheduledRun, HatchetError>

Schedule this task’s workflow to run at a specific future time. See SchedulesClient::create for the underlying API.

pub async fn cron( &self, name: &str, expression: &str, input: &I, options: Option<&CronOptions>, ) -> Result<CronTrigger, HatchetError>

Create a recurring cron trigger for this task’s workflow. See CronsClient::create for the underlying API.