pub struct Workflow<I, O> { /* private fields */ }Expand description
A workflow is a collection of tasks that can be executed by a worker, often forming a directed acyclic graph (DAG). See Hatchet.workflow() for more information.
Implementations
Sourceimpl<I, O> Workflow<I, O>
impl<I, O> Workflow<I, O>
pub fn add_task<P>(self, task: &Task<I, P>) -> Self
Sourcepub async fn schedule(
&self,
trigger_at: DateTime<Utc>,
input: &I,
options: Option<&ScheduleOptions>,
) -> Result<ScheduledRun, HatchetError>
pub async fn schedule( &self, trigger_at: DateTime<Utc>, input: &I, options: Option<&ScheduleOptions>, ) -> Result<ScheduledRun, HatchetError>
Schedule this workflow to run at a specific future time.
See SchedulesClient::create for the underlying API.
Sourcepub async fn cron(
&self,
name: &str,
expression: &str,
input: &I,
options: Option<&CronOptions>,
) -> Result<CronTrigger, HatchetError>
pub async fn cron( &self, name: &str, expression: &str, input: &I, options: Option<&CronOptions>, ) -> Result<CronTrigger, HatchetError>
Create a recurring cron trigger for this workflow.
See CronsClient::create for the underlying API.